@@ -141,13 +141,13 @@ class TPower :
         VCI2=6
 
     def __init__(this):
-        this.no = 0
-        this.available=[0 for _ in range(10)]
-        this.value1=[0 for _ in range(10)]
-        this.fV=[0.0 for _ in range(10)]
-        this.fA=[0.0 for _ in range(10)]
-        this.fRange1=[0.0 for _ in range(10)]
-        this.fRange2=[0.0 for _ in range(10)]
+        this.No = 0
+        this.Avail=[0 for _ in range(10)]
+        this.Value1=[0 for _ in range(10)]
+        this.Voltage=[0.0 for _ in range(10)]
+        this.Current=[0.0 for _ in range(10)]
+        this.Range1=[0.0 for _ in range(10)]
+        this.Range2=[0.0 for _ in range(10)]
 #
 # class TDevice
 #
@@ -174,7 +174,8 @@ class TDevice :
         #    TED_FLOAT fV[10];
         #    TED_FLOAT fA[10];
         #    TED_FLOAT fRange1[10];
-        #    TED_FLOAT fRange2[10];
+        #    TED_FLOAT fRange2[10];dir
+
         #};
 
         this.__PowerStructFmt = 'i'    #    TED_S32 no;    
@@ -283,7 +284,7 @@ class TDevice :
     def WriteCtrlReg(this, regAddr) :
         return this.WriteReg1Byte(regAddr, 0, 1)
 
-    def ReadPowerInfo(this, powerInfo) :
+    def CatchPower(this, powerInfo) :
 
         ret = TDevice_CatchPowerInfo(this.__DeviceHandle,  this.__PowerStructData, 1000)
 
@@ -291,31 +292,31 @@ class TDevice :
 
         resIdx=0
         
-        powerInfo.no = result[resIdx] 
+        powerInfo.No = result[resIdx] 
         resIdx += 1
 
         for i in range(10) :
-            powerInfo.available[i] = result[i+resIdx]
+            powerInfo.Avail[i] = result[i+resIdx]
         resIdx += 10
 
         for i in range(10) :
-            powerInfo.value1[i] = result[i+resIdx]
+            powerInfo.Value1[i] = result[i+resIdx]
         resIdx += 10
 
         for i in range(10) :
-            powerInfo.fV[i] = result[i+resIdx]
+            powerInfo.Voltage[i] = result[i+resIdx]
         resIdx += 10
 
         for i in range(10) :
-            powerInfo.fA[i] = result[i+resIdx]
+            powerInfo.Current[i] = result[i+resIdx]
         resIdx += 10
 
         for i in range(10) :
-            powerInfo.fRange1[i] = result[i+resIdx]
+            powerInfo.Range1[i] = result[i+resIdx]
         resIdx += 10
 
         for i in range(10) :
-            powerInfo.fRange2[i] = result[i+resIdx]
+            powerInfo.Range2[i] = result[i+resIdx]
         resIdx += 10
 
         if ret==0 :
